@@ -16,7 +16,8 @@ class Filter(object):
 
     def posts(self, limit=None, category=None):
         posts = filter(lambda p: not p.draft, self._posts)
-        posts = sorted(posts, key=lambda x: x.publish_date, reverse=True)
+        posts.sort(key=lambda x: x.publish_date, reverse=True)
+
         if category is not None:
             posts = filter(lambda x: x.category in category, posts)
 
