@@ -7,11 +7,15 @@
 import yaml
 
 
+class InvalidContentException(Exception):
+    pass
+
+
 def parse_yaml(src_file):
     with open(src_file, 'r') as f:
         blocks = f.read().split('---', 2)
         if len(blocks) is not 3:
-            raise Exception("Content file could not be parsed %s" % src_file)
+            raise InvalidContentException("Content file could not be parsed %s" % src_file)
         front_matter = yaml.load(blocks[1])
         content = blocks[2].strip()
 
