@@ -6,14 +6,11 @@
 
 import os
 import argparse
-import shutil
 
-from twisted.web.server import Site as twistedsite
-from twisted.web.static import File
-from twisted.internet import reactor
+from flask import Flask
 
 from stanley.parser import parse_yaml
-from stanley.site import Site
+from stanley.site import Site, ContentNotFoundException
 from stanley.config import Config
 from stanley import fs
 
@@ -55,14 +52,24 @@ def build(path, less):
     s.build(less)
 
 
-def server(path):
+def runserver(config_path):
     """
     Run a server
     """
-    resource = File(os.path.join(os.path.dirname(path), 'site'))
-    factory = twistedsite(resource)
-    reactor.listenTCP(8080, factory)
-    reactor.run()
+    config = Config(config_path)
+    site = Site(config, parse_yaml)
+    app = Flask(import_name=__name__, static_folder=config.staticdir, static_url_path='/static', template_folder=config.templatedir, instance_path=config.root)
+
+    @app.route('/', defaults={'path': ''})
+    @app.route('/<path:path>')
+    def catch_all(path):
+        content_filter = site.get_content_filter()
+        try:
+            content = site.get_content_by_url(path)
+            return site.compile(content, content_filter)
+        except ContentNotFoundException:
+            return 'requested content "%s" could not be found' % path, 404
+    app.run(debug=True)
 
 
 class Cli(object):
@@ -102,10 +109,10 @@ class Cli(object):
         args = parser.parse_args()
 
         if args.init is True:
-            init(args.file)
+            init(os.path.abspath(args.file))
         if args.server is True:
-            server(args.file)
+            runserver(os.path.abspath(args.file))
         elif args.build is True:
-            print '\nBuilding %s' % args.file
+            print '\nBuilding %s' % os.path.abspath(args.file)
             print u'----------------------------------------'
-            build(args.file, args.less)
+            build(os.path.abspath(args.file), args.less)
