@@ -1,5 +1,8 @@
 import os.path
-import unittest2 as unittest
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
 
 
 def get_tests():
